@@ -3,7 +3,7 @@
 # @Author  : zbmain
 """
 support: 工具
-├── 环境配置.env:   文件目录 > 跟目录 > Home环境目录[~/.winwin_hub]
+├── 环境配置.env:   文件目录 > Project目录 > HUB目录[~/.winwin_hub] > USER目录
 ├── mysql connect
 ├── odps connect
 ├── holo connect
@@ -24,7 +24,7 @@ from .. import env
 
 
 def __get_exists_file(file: str):
-    """查找目录优先级: support.py目录 > project跟目录 > HUB目录(~/.winwin_hub) > HOME目录(~)"""
+    """查找目录优先级: support.py目录 > Project跟目录 > HUB目录(~/.winwin_hub) > USER目录(~)"""
     dirs = [os.path.dirname(os.path.abspath(__file__)), env.PROJECT_HOME, env.HUB_HOME, env.USER_HOME]
     for _dir in dirs:
         filepath = os.path.join(_dir, file)
@@ -52,7 +52,7 @@ def parse_mysql_uri(uri):
     }
 
 
-def mysql_connect(name="MYSQL_URI"):
+def mysql_connect(name: str = "MYSQL_URI"):
     """MYSQL Connect"""
     import pymysql
     return pymysql.connect(**parse_mysql_uri(os.environ[name]), autocommit=True, cursorclass=pymysql.cursors.DictCursor)
@@ -69,7 +69,7 @@ def parse_oss_uri(uri):
     }
 
 
-def oss_connect(name="OSS_URI", bucket: str = ''):
+def oss_connect(name: str = "OSS_URI", bucket: str = ''):
     """OSS Bucket"""
     import oss2
     config = parse_oss_uri(os.environ[name])
@@ -95,7 +95,7 @@ def parse_odps_uri(uri):
     }
 
 
-def odps_connect(name="ODPS_URI"):
+def odps_connect(name: str = "ODPS_URI"):
     """ODPS / Maxcompute Connect"""
     from odps import ODPS
     return ODPS(**parse_odps_uri(os.environ[name]))
@@ -122,7 +122,7 @@ def parse_ops_uri(uri):
     }
 
 
-def ops_connect(name="OPS_URI"):
+def ops_connect(name: str = "OPS_URI"):
     """OpenSearch Conf"""
     return parse_ops_uri(os.environ[name])
 
@@ -140,7 +140,7 @@ def parse_holo_uri(uri):
     }
 
 
-def holo_connect(name="HOLO_URI"):
+def holo_connect(name: str = "HOLO_URI"):
     """Holo Connect"""
     import psycopg2
     return psycopg2.connect(**parse_holo_uri(os.environ[name]))
@@ -163,7 +163,7 @@ def parse_redis_uri(uri):
 __redis_pool = None
 
 
-def redis_connect(name="REDIS_URI"):
+def redis_connect(name: str = "REDIS_URI"):
     """Redis Connect"""
     import redis
     global __redis_pool
@@ -193,7 +193,7 @@ def parse_nebula_uri(uri=None):
 __nebula_pool = None
 
 
-def nebula_connect(name='NEBULA_URI'):
+def nebula_connect(name: str = 'NEBULA_URI'):
     uri = parse_nebula_uri(os.environ[name])
     from nebula3.gclient.net import ConnectionPool
     from nebula3.Config import Config
@@ -216,6 +216,14 @@ def parse_milvus_uri(uri=None):
     }
 
 
-def milvus_connect(name='MILVUS_URI'):
+def milvus_connect(name: str = 'MILVUS_URI'):
     from pymilvus import connections
     connections.connect(**parse_milvus_uri(os.environ[name]))
+
+
+def sentry_dsn(name: str = 'SENTRY_DSN'):
+    return os.environ[name]
+
+
+def get_environ(name: str):
+    return os.environ[name]
